#
# spec file for package oxygen5
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang
%define kwin_deco 1

Name:           oxygen5
Version:        5.8.2
Release:        2.3
%{!?_plasma5_version: %global _plasma5_version %{version}}
Summary:        Oxygen style, KWin decoration, cursors and sounds
License:        GPL-2.0+
Group:          System/GUI/KDE
Url:            http://www.kde.org
Source:         http://download.kde.org/stable/plasma/%{version}/oxygen-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  extra-cmake-modules >= 0.0.9
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5FrameworkIntegration)
BuildRequires:  cmake(KF5GuiAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5Service)
BuildRequires:  cmake(KF5Wayland) >= %{_plasma5_version}
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
%if %kwin_deco
BuildRequires:  cmake(KDecoration2) >= %{_plasma5_version}
%endif
BuildRequires:  xz
BuildRequires:  cmake(Qt5DBus) >= 5.4.0
BuildRequires:  cmake(Qt5Widgets) >= 5.4.0
BuildRequires:  cmake(Qt5X11Extras) >= 5.4.0
BuildRequires:  pkgconfig(xcb)
%if %kwin_deco
Requires:       oxygen5-decoration
%else
Obsoletes:      oxygen5-decoration
%endif
Requires:       oxygen5-style
Recommends:     oxygen5-sounds
Recommends:     oxygen-cursors
%if %{with lang}
Recommends:     %{name}-lang
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Provides Oxygen style, KWin decoration, cursors and sounds.

%package devel
Summary:        KDE Base Libraries
License:        GPL-2.0+
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}

%description devel
Provides Oxygen style, KWin decoration, cursors and sounds.
Development files.

%package sounds
Summary:        The KDE Workspace Sounds
License:        GPL-2.0+
Group:          System/GUI/KDE
Obsoletes:      oxygen-sounds5 < %{version}
Provides:       oxygen-sounds5 = %{version}

%description sounds
This package contains the default sound set for a K Desktop Environment
workspace.

%package cursors
Summary:        The KDE Workspace Cursors
License:        GPL-3.0+
Group:          System/GUI/KDE
Provides:       oxygen-cursors = %{version}
%if 0%{?suse_version} > 1314 && "%{suse_version}" != "1320"
Obsoletes:      oxygen4-cursors < %{version}
Provides:       oxygen4-cursors = %{version}
Obsoletes:      oxygen-cursors4 < %{version}
Provides:       oxygen-cursors4 = %{version}
%else
Conflicts:      oxygen4-cursors
Conflicts:      oxygen-cursors4
%endif
Obsoletes:      oxygen-cursors5 < %{version}
Provides:       oxygen-cursors5 = %{version}

%description cursors
This package contains the default cursor set for a K Desktop Environment
workspace.

%package style
Summary:        Oxygen style
License:        GPL-2.0+
Group:          System/GUI/KDE
Obsoletes:      oxygen-style5 < %{version}
Provides:       oxygen-style5 = %{version}

%description style
This package contains the libraries of the Oxygen style.

%if %kwin_deco
%package decoration
Summary:        Oxygen's KWin decoration
License:        GPL-2.0+
Group:          System/GUI/KDE
Supplements:    packageand(oxygen5-style:kwin5)
Obsoletes:      oxygen-decoration5 < %{version}
Provides:       oxygen-decoration5 = %{version}
%requires_eq oxygen5-style

%description decoration
This package contains the libraries Oxygen's KWin decoration.
%endif

%lang_package
%prep
%setup -q -n oxygen-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
%make_jobs

%install
  %kf5_makeinstall -C build
%if %{with lang}
  %kf5_find_lang
%endif

%post     style -p /sbin/ldconfig

%postun   style -p /sbin/ldconfig

%if %kwin_deco
%post     decoration   -p /sbin/ldconfig

%postun   decoration   -p /sbin/ldconfig
%endif

%files
%defattr(-,root,root)
%doc COPYING*

%files style
%defattr(-,root,root)
%doc COPYING*
%{_kf5_bindir}/oxygen-demo5
%{_kf5_bindir}/oxygen-settings5
%{_kf5_libdir}/liboxygenstyle5.so.*
%{_kf5_libdir}/liboxygenstyleconfig5.so.*
%{_kf5_plugindir}/kstyle_oxygen_config.so
%{_kf5_plugindir}/styles/
%{_kf5_sharedir}/kstyle/
%{_kf5_plasmadir}/
%dir %{_kf5_servicesdir}
%{_kf5_servicesdir}/oxygenstyleconfig.desktop
%dir %{_kf5_iconsdir}/hicolor/*/
%dir %{_kf5_iconsdir}/hicolor/*/apps
%{_kf5_iconsdir}/hicolor/*/apps/oxygen-settings.png

%if %kwin_deco
%files decoration
%defattr(-,root,root)
%doc COPYING*
%{_kf5_plugindir}/org.kde.kdecoration2/
%dir %{_kf5_servicesdir}
%{_kf5_servicesdir}/oxygendecorationconfig.desktop
%endif

%files sounds
%defattr(-,root,root)
%doc COPYING*
%{_kf5_sharedir}/sounds/

%files cursors
%defattr(-,root,root)
%doc COPYING*
%{_kf5_sharedir}/icons/Oxygen_*/
%{_kf5_sharedir}/icons/KDE_Classic/

%files devel
%defattr(-,root,root)
%doc COPYING*
%{_kf5_libdir}/liboxygenstyleconfig5.so
%{_kf5_libdir}/liboxygenstyle5.so

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Fix self-obsoletion
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Use %%{_plasma5_version} again, define it if needed
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Wed Dec 23 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
- Added kcmutils-devel BuildRequires
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Tue Jul 14 2015 hrvoje.senjan@gmail.com
- Obsolete oxygen4-cursors on openSUSE > 13.2. For 13.2 and older,
  conflict with both old and new named cursors from kdebas4-workspace
* Tue Jul 14 2015 tittiatcoke@gmail.com
- Conflict now with oxygen4-cursors, due to the renaming of the
  KDE4 based package.
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- KWin decoration is again built with 5.3 release: BuildRequire
  libkdecoration2-devel instead of libkdecorations-devel
- Let the decoration Supplements kwin5 and oxygen5-style
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Don't build the decoration, not (yet) ported to libkdecoration2
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * Fixed color role for accelerator
  * Added inputWidgetEngine, for abstract item views, line editors,
    spinboxes and comboboxes it is needed to avoid animation
    conflicts between lists and buttons (when, e.g. there is a
    checkbox inside a list)
  * Removed support for Q3ListView
  * Manually calculate viewport update rect on header hover change
  * Remove mnemonic underlines when alt-tabbing
  * CMake: use the kde4workspace include dir
  * CMake: fix searching for pkg-config
  * Fixed member initialization removed unused headers
    backported from breeze
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Added WeakPointer typedef to oxygendecorationdefines to allow
    compilation against both KDE4 and KF5, kde#340597
  * Properly handle RTL for corner rects and tabbar
    (kde#340155, kde#340150)
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Sat Oct 25 2014 hrvoje.senjan@gmail.com
- Recommend lang subpackage
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor changes to Oxygen style and decoration
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Wed Sep 24 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140924 (rbc60753):
  * Streamline of the style
  * New Oxygen Look-and-feel package
- Drop crasher.diff, obsoleted by the update
- Swap libxcb-devel BuildRequires with pkgconfig(x11-xcb) and
  pkgconfig(xcb)
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Thu Jun 26 2014 hrvoje.senjan@gmail.com
- Mark cursors subpackage with correct (GPL-3.0+) license
* Fri Jun  6 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0 - second beta of Plasma 5 release
* Tue Jun  3 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
- Add Source URL
* Sun May 18 2014 hrvoje.senjan@gmail.com
- Activate oxygen5 package
